<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Controller_Request_HttpTestCase extends Zend_Controller_Request_HttpTestCase
{
    protected $_localServerChanges = array();
    protected $_localGetChanges = array();
    protected $_localGetReset = false;

    public function __construct($uri = null)
    {
        parent::__construct($uri);
    }

    /**
     * Set a member of the $_SERVER superglobal
     *
     * @param string $key
     * @param mixed $value
     * @return void
     */
    public function setServer($key, $value)
    {
        $this->_localServerChanges[$key] = $value;
    }

    /**
     * Retrieve a member of the $_SERVER superglobal
     *
     * If no $key is passed, returns the entire $_SERVER array.
     *
     * @param string $key
     * @param mixed $default Default value to use if key not found
     * @return mixed Returns null if key does not exist
     */
    public function getServer($key = null, $default = null)
    {
        $serverArray = array_merge($_SERVER, $this->_localServerChanges);

        if (null === $key) {
            return $serverArray;
        }

        return (isset($serverArray[$key])) ? $serverArray[$key] : $default;
    }

    public function resetQuery()
    {
        $this->_localGetReset = true;
        $this->_localGetChanges = array();
    }

    /**
     * Set GET values
     *
     * @param  string|array $spec
     * @param  null|mixed $value
     * @return Zend_Controller_Request_Http
     */
    public function setQuery($spec, $value = null)
    {
        if ((null === $value) && !is_array($spec)) {
            require_once 'Zend/Controller/Exception.php';
            throw new Zend_Controller_Exception('Invalid value passed to setQuery(); must be either array of values or key/value pair');
        }
        if ((null === $value) && is_array($spec)) {
            foreach ($spec as $key => $value) {
                $this->setQuery($key, $value);
            }
            return $this;
        }

        $this->_localGetChanges[(string) $spec] = $value;
        return $this;
    }

    /**
     * Retrieve a member of the $_GET superglobal
     *
     * If no $key is passed, returns the entire $_GET array.
     *
     * @todo How to retrieve from nested arrays
     * @param string $key
     * @param mixed $default Default value to use if key not found
     * @return mixed Returns null if key does not exist
     */
    public function getQuery($key = null, $default = null)
    {
        if ($this->_localGetReset)
        {
            $getArray = array_merge($this->_localGetChanges);
        }
        else
        {
            $getArray = array_merge($_GET, $this->_localGetChanges);
        }

        if (null === $key) {
            return $getArray;
        }

        return (isset($getArray[$key])) ? $getArray[$key] : $default;
    }

    /**
     * Retrieve only user params (i.e, any param specific to the object and not the environment)
     *
     * @return array
     */
    public function getUserParams()
    {
        $params = array_merge(parent::getUserParams(), $this->getQuery(), $this->getPost());
        return $params;
    }
}