<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Language
{

    /**
     *
     * @var string
     */
    const DEFAULT_SESSION_KEY = 'DZF_Language';

    /**
     *
     * @var DZF_Language
     */
    protected static $_instance;

    /**
     *
     * @var Zend_Namespace_Session
     */
    protected $_session;

    /**
     *
     * @var array
     */
    protected $_translators;

    /**
     *
     * @var boolean
     */
    protected $_defaultLanguage = false;

    /**
     *
     */
    protected function __construct()
    {
        $this->_session = new Zend_Session_Namespace(self::DEFAULT_SESSION_KEY);
        $this->_translators = array();
        //$this->_initLanguage();
    }

    /**
     * @return DZF_Language
     */
    public static function getInstance()
    {
        if (null === self::$_instance) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    public function addTranslator(Zend_Translate $translator)
    {
        if (!$translator instanceof Zend_Translate) {
            throw new Zend_Translate_Exception('Invalid translator specified');
        }
        $this->_translators[] = $translator;
    }

    public function initTranslators()
    {
        $this->_initLanguage();
        $this->_initTranslators();
    }

    /**
     *
     */
    protected function _initLanguage()
    {
        $language = $this->getLanguage();

        if (empty($language))
        {
            /*
            $locale = new Zend_Locale();
            $language = $locale->getLanguage();
            //check if browser language is available
            if (!$this->isAvailable($language))
            {
                //get default language if there is no translation
                $locale = new Zend_Locale(Zend_Locale::ZFDEFAULT);
                $language = $locale->getLanguage();
                if (!$this->isAvailable($language))
                {
                    throw new Zend_Translate_Exception(
                        'No translation for default language specified.'
                    );
                }
            }
            $this->_defaultLanguage = true;
            $this->_setLanguage($language);*/

            $this->_defaultLanguage = true;
            $this->_setLanguage(APPLICATION_LANGUAGE);
        }
    }

    protected function _initTranslators()
    {
        foreach ($this->_translators as $translator) {
            $translator->setLocale($this->getLanguage());
        }
    }

    /**
     * @return string
     */
    public function getLanguage()
    {
        return $this->_session->language;
    }

    public function setLanguage($language)
    {
        if (!$this->isAvailable($language)) {
            throw new Zend_Translate_Exception(
                sprintf(
                    "Language '%s' is not available",
                    $language
                )
            );
        }
        $this->_setLanguage($language);
        $this->_initTranslators();
    }

    /**
     *
     * @param string $language
     */
    protected function _setLanguage($language)
    {
        $this->_session->language = $language;
    }

    /**
     *
     * @param string $language
     * @return boolean
     */
    public function isAvailable($language)
    {
        foreach ($this->_translators as $translator) {
            if (!$translator->isAvailable($language)) {
                return false;
            }
        }
        return true;
    }

    /**
     * @return boolean
     */
    public function hasDefaultLanguage()
    {
        return $this->_defaultLanguage;
    }

    /**
     * @param string $input
     * @return string
     */
    public static function markForGettext($input)
    {
        return $input;
    }
}