<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Mail extends Zend_Mail
{
    /**
     * @var string
     */
    protected $_bodyHtmlRaw = '';

    /**
     * @var string
     */
    protected $_bodyTextRaw = '';

    /**
     * @var string
     */
    protected $_subjectRaw = '';

    public function setSubject($subject)
    {
        $this->_subjectRaw = $subject;

        return parent::setSubject($subject);
    }

    public function getSubjectRaw()
    {
        return $this->_subjectRaw;
    }

    public function setBodyHtml($html, $charset = null, $encoding = Zend_Mime::ENCODING_QUOTEDPRINTABLE)
    {
        $this->_bodyHtmlRaw = $html;

        return parent::setBodyHtml($html, $charset, $encoding);
    }

    public function setBodyText($txt, $charset = null, $encoding = Zend_Mime::ENCODING_QUOTEDPRINTABLE)
    {
        $this->_bodyTextRaw = $txt;

        return parent::setBodyText($txt, $charset, $encoding);
    }

    public function getBodyHtmlRaw()
    {
        return $this->_bodyHtmlRaw;
    }

    public function getBodyTextRaw()
    {
        return $this->_bodyTextRaw;
    }

    public static function mailException(Exception $exception)
    {
        $mailContent  = 'exception type: '.get_class($exception)."\n\n";
        $mailContent .= 'exception message: '.$exception->getMessage()."\n\n";
        $mailContent .= 'exception trace: '.$exception->getTraceAsString()."\n\n";
        $mailContent .= '$_REQUEST: '.var_export($_REQUEST, true)."\n\n";
        $mailContent .= '$_GET: '.var_export($_GET, true)."\n\n";
        $mailContent .= '$_POST: '.var_export($_POST, true)."\n\n";
        $mailContent .= '$_SERVER: '.var_export($_SERVER, true)."\n\n";
        $mailContent .= '$_COOKIE: '.var_export($_COOKIE, true)."\n\n";
        $mailContent .= '$_SESSION: '.var_export(DZF_Exception::filterSession($_SESSION), true)."\n\n";

        if ($exception instanceof DZF_Exception && isset($exception->debugData))
        {
            $mailContent .= 'debugData: '.$exception->debugData."\n\n";
        }

        $exceptionMail = new Zend_Mail('utf-8');
        $exceptionMail->setSubject('['.APPLICATION_ENV.'] '.APPLICATION_NAME.' exception mail');
        $exceptionMail->setBodyText($mailContent);
        $exceptionMail->addTo(Zend_Registry::get('debugging.emailtarget'));
        $exceptionMail->send();
    }
}