<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Validate_Nickname extends Zend_Validate_Abstract
{
    const INVALID = 'invalid';
    const TOOSHORT = 'toolong';
    const TOOLONG = 'tooshort';

    protected $_pattern = '/^[\pL0-9\-_\^°~\'´`[:blank:]]+$/ui';
    protected $_minLength = 3;
    protected $_maxLength = 20;

    protected $_messageTemplates = array(
        self::INVALID => "'%value%' enthält ungültige Zeichen. Erlaubt sind Buchstaben, Zahlen, Leerzeichen und Sonderzeichen wie \"~^°-\".",
        self::TOOSHORT => "Der Benutzername ist zu kurz. (3-20 Zeichen)",
        self::TOOLONG => "Der Benutzername ist zu lang. (3-20 Zeichen)"
    );

    public function isValid($value)
    {
        $this->_setValue($value);

        $length = mb_strlen($value);
        if ($length < $this->_minLength)
        {
            $this->_error(self::TOOSHORT);
            return false;
        }
        elseif ($length > $this->_maxLength)
        {
            $this->_error(self::TOOLONG);
            return false;
        }

        $regexValidator = new Zend_Validate_Regex($this->_pattern);
        if (!$regexValidator->isValid($value))
        {
            $this->_error(self::INVALID);
            return false;
        }

        return true;
    }
}