<?php
/**
 * DZF
 *
 * LICENSE: Redistribution and use in source and binary forms, with or without
 * modifications, are not permitted.
 *
 * @copyright Deubert IT-Solutions © 2012-2014 All rights reserved
 * @package DZF
 */

/**
 * @author Karsten Deubert <info@deubert.it>
 */
class DZF_Validate_Street extends Zend_Validate_Abstract
{
	const INVALID = 'invalid';
	const TOOSHORT = 'toolong';
	const TOOLONG = 'tooshort';

    protected $_pattern = '/^[\pL\d[:blank:].\-´`\'’&]*[\pL]+[\pL\d[:blank:].\-´`\'’&]*$/ui';
    protected $_minLength = 3;
    protected $_maxLength = 80;

	protected $_messageTemplates = array(
		self::INVALID => "'%value%' enthält ungültige Zeichen.",
		self::TOOSHORT => "Die Straße ist zu kurz.",
		self::TOOLONG => "Die Straße ist zu lang."
	);

	public function isValid($value)
	{
		$this->_setValue($value);

        $length = mb_strlen($value);
        if ($length < $this->_minLength)
        {
            $this->_error(self::TOOSHORT);
            return false;
        }
        elseif ($length > $this->_maxLength)
        {
            $this->_error(self::TOOLONG);
            return false;
        }

        $regexValidator = new Zend_Validate_Regex($this->_pattern);
        if (!$regexValidator->isValid($value))
        {
            $this->_error(self::INVALID);
            return false;
        }

		return true;
	}
}